@@ -1,4 +1,4 @@
 """Full documentation is at https://photini.readthedocs.io/"""
 
-__version__ = '2022.9.0'
-build = '2259 (7e06f88)'
+__version__ = '2022.10.0.2'
+build = '2278 (08b9228)'
