@@ -16,8 +16,6 @@
 ##  along with this program.  If not, see
 ##  <http://www.gnu.org/licenses/>.
 
-from __future__ import unicode_literals
-
 import importlib
 import logging
 from optparse import OptionParser
@@ -51,6 +49,7 @@ translate = QtCore.QCoreApplication.translate
 
 
 class QTabBar(QtWidgets.QTabBar):
+    @catch_all
     def tabSizeHint(self, index):
         size = super(QTabBar, self).tabSizeHint(index)
         size.setWidth(max(size.width(), width_for_text(self, 'x' * 10)))
@@ -113,7 +112,7 @@ class InstanceServer(QtNetwork.QTcpServer):
         super(InstanceServer, self).__init__(*arg, **kw)
         config = BaseConfigStore('instance')
         self.newConnection.connect(self.new_connection)
-        if not self.listen(QtNetwork.QHostAddress.LocalHost):
+        if not self.listen(QtNetwork.QHostAddress.SpecialAddress.LocalHost):
             logger.error('Failed to start instance server:', self.errorString())
             return
         config.set('server', 'port', self.serverPort())
@@ -124,7 +123,8 @@ class InstanceServer(QtNetwork.QTcpServer):
     def new_connection(self):
         window = self.parent().window()
         window.setWindowState(
-            (window.windowState() & ~Qt.WindowMinimized) | Qt.WindowActive)
+            (window.windowState() & ~Qt.WindowState.WindowMinimized) |
+            Qt.WindowState.WindowActive)
         window.raise_()
         while self.hasPendingConnections():
             socket = self.nextPendingConnection()
@@ -176,9 +176,10 @@ class MainWindow(QtWidgets.QMainWindow):
         # restore size and state
         size = self.width(), self.height()
         self.resize(*self.app.config_store.get('main_window', 'size', size))
-        window_state = self.app.config_store.get('main_window', 'state', 0)
-        full_screen = window_state & int(
-            Qt.WindowMaximized | Qt.WindowFullScreen)
+        window_state = Qt.WindowState(
+            self.app.config_store.get('main_window', 'state', 0))
+        full_screen = window_state & (
+            Qt.WindowState.WindowMaximized | Qt.WindowState.WindowFullScreen)
         if full_screen:
             self.setWindowState(self.windowState() | full_screen)
         # image selector
@@ -189,7 +190,7 @@ class MainWindow(QtWidgets.QMainWindow):
         # start instance server
         instance_server = InstanceServer(parent=self)
         instance_server.new_files.connect(
-            self.image_list.open_file_list, Qt.QueuedConnection)
+            self.image_list.open_file_list, Qt.ConnectionType.QueuedConnection)
         # update config file
         if self.app.config_store.config.has_section('tabs'):
             conv = {
@@ -238,11 +239,11 @@ class MainWindow(QtWidgets.QMainWindow):
         # file menu
         file_menu = self.menuBar().addMenu(translate('MenuBar', 'File'))
         action = file_menu.addAction(translate('MenuBar', 'Open files'))
-        action.setShortcuts(QtGui.QKeySequence.Open)
+        action.setShortcuts(QtGui.QKeySequence.StandardKey.Open)
         action.triggered.connect(self.image_list.open_files)
         self.save_action = file_menu.addAction(
             translate('MenuBar', 'Save changes'))
-        self.save_action.setShortcuts(QtGui.QKeySequence.Save)
+        self.save_action.setShortcuts(QtGui.QKeySequence.StandardKey.Save)
         self.save_action.setEnabled(False)
         self.save_action.triggered.connect(self.image_list.save_files)
         self.fix_thumbs_action = file_menu.addAction(
@@ -260,8 +261,8 @@ class MainWindow(QtWidgets.QMainWindow):
         self.selected_actions = self.image_list.add_selected_actions(file_menu)
         file_menu.addSeparator()
         action = file_menu.addAction(translate('MenuBar', 'Quit'))
-        action.setShortcuts(
-            [QtGui.QKeySequence.Quit, QtGui.QKeySequence.Close])
+        action.setShortcuts([QtGui.QKeySequence.StandardKey.Quit,
+                             QtGui.QKeySequence.StandardKey.Close])
         action.triggered.connect(
             QtWidgets.QApplication.instance().closeAllWindows)
         # options menu
@@ -316,11 +317,11 @@ class MainWindow(QtWidgets.QMainWindow):
         action.triggered.connect(self.open_docs)
         # main application area
         self.central_widget = QtWidgets.QSplitter()
-        self.central_widget.setOrientation(Qt.Vertical)
+        self.central_widget.setOrientation(Qt.Orientation.Vertical)
         self.central_widget.setChildrenCollapsible(False)
         self.tabs = QtWidgets.QTabWidget()
         self.tabs.setTabBar(QTabBar())
-        self.tabs.setElideMode(Qt.ElideRight)
+        self.tabs.setElideMode(Qt.TextElideMode.ElideRight)
         self.tabs.currentChanged.connect(self.new_tab)
         self.tabs.setMovable(True)
         self.tabs.tabBar().tabMoved.connect(self.tab_moved)
@@ -504,10 +505,12 @@ jim@jim-easterbrook.me.uk</a><br /><br />
 
     @catch_all
     def resizeEvent(self, event):
-        window_state = int(self.windowState())
-        self.app.config_store.set('main_window', 'state', window_state)
-        if window_state & int(
-                Qt.WindowMinimized | Qt.WindowMaximized | Qt.WindowFullScreen):
+        window_state = self.windowState()
+        self.app.config_store.set(
+            'main_window', 'state', flag_to_int(window_state))
+        if window_state & (Qt.WindowState.WindowMinimized |
+                           Qt.WindowState.WindowMaximized |
+                           Qt.WindowState.WindowFullScreen):
             return
         size = self.width(), self.height()
         self.app.config_store.set('main_window', 'size', size)
@@ -521,7 +524,7 @@ def main(argv=None):
         sys.argv = argv
     if qt_version_info < (6, 0):
         QtWidgets.QApplication.setAttribute(Qt.AA_EnableHighDpiScaling, True)
-    QtWidgets.QApplication.setAttribute(Qt.AA_UseHighDpiPixmaps, True)
+        QtWidgets.QApplication.setAttribute(Qt.AA_UseHighDpiPixmaps, True)
     # let Qt handle its options
     app = QtWidgets.QApplication(sys.argv)
     # get remaining argument list after Qt has swallowed its options
