@@ -652,7 +652,7 @@ class MD_Thumbnail(MD_Dict):
     @staticmethod
     def data_from_image(image, max_size=60000):
         buf = QtCore.QBuffer()
-        buf.open(buf.WriteOnly)
+        buf.open(buf.OpenModeFlag.WriteOnly)
         quality = 95
         while quality > 10:
             image.save(buf, 'JPEG', quality)
@@ -910,7 +910,9 @@ class LangAltDict(dict):
         return any(self.values())
 
     def __eq__(self, other):
-        return not self.__ne__(other)
+        if isinstance(other, LangAltDict):
+            return not self.__ne__(other)
+        return super(LangAltDict, self).__eq__(other)
 
     def __ne__(self, other):
         if isinstance(other, LangAltDict):
